Learn R Programming

flood (version 0.1.1)

RegioHill: Regional EVI estimator

Description

Estimation of the positive extreme value index (EVI) based on multiple local Hill estimators. We assume heavy-tail homogeneity, i.e., all local EVI's are the same.

Usage

RegioHill(x, k, k.qu = 20, type = "evopt", alpha = 0.05, ci = "nonlog")

Arguments

x
Vector or matrix of observations
k
Number of relative excesses involved in the estimation of the extreme value index gamma. If k is missing, it will be set to
  • $k=floor(2*n^(2/3))$, where n is the sample length of the vector x after removing missing values
  • $k=floor(2*n^(2/3)/d^(1/3))$, where d is the number of columns of the matrix x and n the length of each column after removing missing values.
k.qu
Tuning parameter for estimation of empirical variance; only needed if type="opt".
type
Choose either "evopt" if extreme value dependent, "ind" if independent or "opt" for arbitrarily dependent components.
alpha
Confidence level for confidence interval.
ci
Either "nonlog" for standart or "log" for non-standart confidence interval based on log-transformed hill estimates.

Value

List of
  • est a weighted average of local Hill estimates.
  • Sigma an estimate of the corresponding variance matrix.
  • CI a confidence interval.

Examples

Run this code
library("evd")
x1 <- rgev(150, loc = 2, scale = 1, shape=0.4)
hill(x1, k=20)
x2 <- rgev(100, loc = 2.5, scale = 1, shape=0.4)
x2 <- c(x2, rep(NA, 50))
x <- cbind(x1, x2)
k <- c(40, 30)
RegioHill(x, k)

Run the code above in your browser using DataLab