Learn R Programming

flood (version 0.1.1)

RegioWeissman: Quantile estimation: Weissman's extrapolation

Description

Estimation of the p-quantile based on multiple local Hill estimators and Weissman's extrapolation formula. We assume heavy-tail homogeneity, i.e., all local EVI's are the same.

Usage

RegioWeissman(x, j = 1, p, k, k.qu = 20, type = "evopt", alpha = 0.05)

Arguments

x
Vector or matrix of observations
j
The number of the target site, i.e., if j=2 the p-quantile of the second column of x is estimated.
p
The probability of interest; should be between $1-k_j/n_j$ and 1, where $n_j$ is the sample length of the j-th column.
k
Number of relative excesses involved in the estimation of the extreme value index gamma. If k is missing, it will be set to
  • $k=floor(2*n^(2/3))$, where n is the sample length of the vector x after removing missing values
  • $k=floor(2*n^(2/3)/d^(1/3))$, where d is the number of columns of the matrix x and n the length of each column after removing missing values.
k.qu
Tuning parameter for estimation of empirical variance; only needed if type="opt".
type
Choose either "evopt" if extreme value dependent, "ind" if independent or "opt" for arbitrarily dependent components.
alpha
Confidence level for confidence interval.

Value

List of
  • est Point estimate of p-quantile of column j
  • CI the corresponding alpha-confidence interval
  • EVI estimate of the extreme value index
  • k tail sample size
  • p a probability
  • u.kn (n-k)-th largest observation, where n is the sample length at station j after removing missing values
  • description a short description.

Examples

Run this code
library("evd")
# sample observations of 75 years at one station:
x <- rgev(75, 0, 1, 0) # x is a vector
RegioWeissman(x=x, p=0.95)

x2 <- c(NA, NA, x[1:60], NA, x[61:75]) # vector of observations with missing values
RegioWeissman(x=x2, p=0.95) # NAs will be removed

# sample observations of 100 years at 4 stations:
set.seed(1053)
x <- matrix(rgev(400, 2, 1, 0.3), ncol=4)
RegioWeissman(x=x, p=0.9, j=3)

# With missing values:
x2 <- x
x2[sample(100, 12),2] <- NA
RegioWeissman(x=x2, p=0.9, j=3)

Run the code above in your browser using DataLab