Learn R Programming

flood (version 0.1.1)

TailAnova: Heavy-tail ANOVA

Description

A test of heavy-tail homogeneity, that is, equality of the positive extreme value index for all d columns of x.

Usage

TailAnova(x, k, k.qu = 20, type = "evopt", cf = TRUE)

Arguments

x
Matrix of observations
k
Number of relative excesses involved in the estimation of the extreme value index gamma. If k is missing, it will be set to $k=floor(2*n^(2/3)/d^(1/3))$, where d is the number of columns of the matrix x and n the length of each column after removing missing values.
k.qu
Tuning parameter for estimation of empirical variance; only needed if type="opt".
type
Choose either "evopt" if extreme value dependent, "ind" if independent or "opt" for arbitrarily dependent components.
cf
If TRUE, a correctur factor is used, which improves the size at the cost of power.

Value

Test statistic and p-value.

Examples

Run this code
library("evd")
set.seed(6754)
x1 <- rgev(150, loc = 2, scale = 1, shape=0.4)
x2 <- rgev(150, loc = 2.5, scale = 1, shape=0.1) # H_0 violated because of different shapes
x <- cbind(x1, x2)
TailAnova(x)

x1 <- rgev(150, loc = 2, scale = 1, shape=0.3)
x2 <- rgev(150, loc = 2.5, scale = 1, shape=0.3) # H_0 not violated because of same shapes
x <- cbind(x1, x2)
TailAnova(x)

Run the code above in your browser using DataLab