Calculates annual maxima from seasonal maxima of two seasons.
Usage
seas2ann(x1, x2, na.rm = TRUE)
Arguments
x1
vector or matrix of observations from season 1 (rows: observations, columns: stations).
x2
vector or matrix of observations from season 2 (rows: observations, columns: stations).
na.rm
logical. TRUE: the annual maximum will be calculated even if one
observation of the two seasons is a missing value, e.g. winter maximum is 58 and summer
maximum is NA the annual maximum is 58. If both observations are NA, the annual maximum is set to NA, too.
FALSE: the annual maximum will be set to NA if one
observation of the two seasons is a missing value, e.g. winter maximum is 58 and summer maximum
is NA the annual maximum is NA.
Value
Matrix of annual observations (rows: observations, columns: stations).